/*!
  * Material Style rainbow.js v3.1.0-alpha1 (https://materialstyle.github.io/)
  * Copyright 2018-2023 Neeraj Kumar Das (https://github.com/nkdas91)
  * Licensed under MIT (https://github.com/materialstyle/materialstyle/blob/master/LICENSE)  
  * This a fork of Bootstrap: Initial license below
  * 
  * Bootstrap rainbow.js v5.3.0 (https://getbootstrap.com/)
  * Copyright 2011-2023 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
  */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('./base-component.js'), require('./dom/event-handler.js'), require('./dom/selector-engine.js'), require('./util/index.js')) :
  typeof define === 'function' && define.amd ? define(['./base-component', './dom/event-handler', './dom/selector-engine', './util/index'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.Rainbow = factory(global.BaseComponent, global.EventHandler, global.SelectorEngine, global.Index));
})(this, (function (BaseComponent, EventHandler, SelectorEngine, index_js) { 'use strict';

  /**
   * --------------------------------------------------------------------------
   * Material Style rainbow.js
   * Licensed under MIT (https://github.com/materialstyle/materialstyle/blob/master/LICENSE)
   * --------------------------------------------------------------------------
   */

  /**
   * Constants
   */

  const NAME = 'rainbow';
  const DATA_KEY = 'bs.rainbow';
  const EVENT_KEY = `.${DATA_KEY}`;
  const DATA_API_KEY = '.data-api';
  const EVENT_LOAD_DATA_API = `load${EVENT_KEY}${DATA_API_KEY}`;

  /**
   * Class definition
   */

  class Rainbow extends BaseComponent {
    constructor(element) {
      super(element);
      this._element = element;
      this.initRainbow();
    }
    static get NAME() {
      return NAME;
    }
    static jQueryInterface() {
      return this.each(function () {
        Rainbow.getOrCreateInstance(this);
      });
    }
    initRainbow() {
      const colorBars = this._element.querySelectorAll('.color-bar');
      const barCount = colorBars.length;
      for (let i = 0; i < barCount; i++) {
        colorBars[i].style.animation = `m-rainbow ${barCount}s cubic-bezier(0.165, 0.84, 0.44, 1) ${i}s infinite`;
      }
    }
  }
  EventHandler.on(window, EVENT_LOAD_DATA_API, () => {
    for (const el of SelectorEngine.find('.progress-bar-rainbow')) {
      Rainbow.getOrCreateInstance(el);
    }
  });

  /**
   * jQuery
   */

  index_js.defineJQueryPlugin(Rainbow);

  return Rainbow;

}));
//# sourceMappingURL=rainbow.js.map
